# saint72

Библиотека для генерации файла с кодом в корне проекта.

## Использование

```python
import saint72
saint72.create_code_file()
```

В результате в корне проекта появится файл `saint72_generated.py`.
